==> cms-db_v0.7.11.tar.gz: admin/update/download.php <==
<?php
/*  cms-db  Copyright (C) 2007-2009 Jan Hoffmann
    This program comes with ABSOLUTELY NO WARRANTY; for details see /admin/version.php.
    This is free software, and you are welcome to redistribute it under certain conditions; see /admin/version.php for details.  */
chdir('../');
include('checkuser.inc.php');
checkuser('root');
include('locale.inc.php');
$locale = new LocalizingClass('update');
?>
<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Strict//EN"
     "http://www.w3.org/TR/xhtml1/DTD/xhtml1-strict.dtd">
<html xmlns="http://www.w3.org/1999/xhtml">
<head>
<title><?php locale('title_download') ?></title>
<meta http-equiv="content-type" content="text/html; charset=utf-8" />
<link rel="stylesheet" type="text/css" href="../style.css" />
<script type="text/javascript" src="../jquery.js"></script>
<script type="text/javascript" src="../progressbar.js"></script>
<link rel="stylesheet" type="text/css" href="../progressbar.css" />
</head>
<body>

<h1><?php locale('title_download') ?></h1>
<?php
$n = "\n";
echo '<p id="progressbar">&nbsp;</p>'.$n;
echo '<p id="status" style="font-weight: bold; font-size: 1.1em">&nbsp;</p>'.$n;
echo '<script type="text/javascript">$("#status").text(\''.locale_escape('desc_ftpconn-test',"'",true).'\');</script>'.$n;
echo '<script type="text/javascript">drawProgressBar("#progressbar", 20, "em", "#2784f5", "#ccc", 0);</script>'.$n;
flush();

$error = false;
include('../data/settings/ftp.inc.php');
$c = ftp_connect($ftpserver);
if ($c !== false) {
	@ftp_set_option($c, FTP_TIMEOUT_SEC, 10);
	@ftp_pasv($c, true);
	if (@ftp_login($c, $ftpuser, $ftppw)) {
		$folders = ftp_nlist($c, $ftpdir);
		if ($folders !== false) {
			if (in_array($ftpdir.'/admin', $folders)
			&& in_array($ftpdir.'/data', $folders)
			&& in_array($ftpdir.'/functions.inc.php', $folders)) {
				echo '<p>'.locale('desc_ftpconn-established',true).'</p>'.$n;
				echo '<script type="text/javascript">drawProgressBar("#progressbar", 20, "em", "#2784f5", "#ccc", 0.05);</script>'.$n;
				flush();
			} else { $error = true; }
		} else { $error = true; }
	} else { $error = true; }
} else { $error = true; }

if ($error) {
	echo '<p>'.sprintf(locale('desc_change-ftpsettings',true),'download.php?'.SID).'</p>';
	echo '<p><a href="../ftpsettings.php?download=true&'.SID.'">'.locale('link_change-ftpsettings',true).'</a></p>';
	echo '<script type="text/javascript">$("#status").text(\''.locale_escape('title_error',"'",true).'\');</script>'.$n;
} else {
	echo '<script type="text/javascript">$("#status").text(\''.locale_escape('desc_download-start',"'",true).'\');</script>'.$n;
	flush();

	$version = trim(file_get_contents('../data/version.txt'));
	$curl_version = curl_version();
	$useragent = 'cms-db/'.$version.' libcurl/'.$curl_version['version'];

	$q = $_GET['q'];
	$ch = curl_init();
	curl_setopt($ch, CURLOPT_URL, 'http://update.cms-db.de/update/v1/api.php?version-unstable'); // update as soon as stable version is available
	curl_setopt($ch, CURLOPT_RETURNTRANSFER, 1);
	curl_setopt($ch, CURLOPT_USERAGENT, $useragent);
	$version = curl_exec($ch);
	curl_close($ch);

	$ch = curl_init();
	curl_setopt($ch, CURLOPT_URL, 'http://update.cms-db.de/update/v1/api.php?download/'.$version);
	curl_setopt($ch, CURLOPT_RETURNTRANSFER, 1);
	curl_setopt($ch, CURLOPT_USERAGENT, $useragent);
	$url = curl_exec($ch);
	curl_close($ch);

	$ch = curl_init();
	$fp = fopen('../data/update.tar.gz', 'wb+');
	curl_setopt($ch, CURLOPT_URL, $url);
	curl_setopt($ch, CURLOPT_FILE, $fp);
	curl_setopt($ch, CURLOPT_HEADER, 0);
	curl_setopt($ch, CURLOPT_USERAGENT, $useragent);
	curl_exec($ch);
	curl_close($ch);
	fclose($fp);

	echo '<p>'.locale('desc_download-finished',true).'</p>'.$n;
	echo '<script type="text/javascript">drawProgressBar("#progressbar", 20, "em", "#2784f5", "#ccc", 0.10);</script>'.$n;
	flush();



	echo '<script type="text/javascript">$("#status").text(\''.locale_escape('desc_extract-start',"'",true).'\');</script>'.$n;
	flush();

	if (!is_dir('../data/update')) mkdir('../data/update');


	if ((@include 'Archive/Tar.php') == true) {
		$a = new Archive_Tar('../data/update.tar.gz');
		$a->extract('../data/update');
		$filecount = 0;
		function countfiles($item, $key) {
			$filecount =& $GLOBALS['filecount'];
			if ($item['typeflag'] == 0) $filecount++;
		}
		array_walk($a->listContent(), 'countfiles');
		unset($a);
	} else {
		include('tar.inc.php');
		$a = new gzip_file('../update.tar.gz'); // path relative from basedir
		$a->set_options(array('basedir' => '../data/update', 'overwrite' => 1));
		$a->extract_files();
		$filecount = count($a->files);
		unset($a);
	}

	echo '<p>'.locale('desc_extract-finished',true).'</p>'.$n;
	echo '<script type="text/javascript">drawProgressBar("#progressbar", 20, "em", "#2784f5", "#ccc", 0.15);</script>'.$n;
	flush();



	echo '<script type="text/javascript">$("#status").text(\''.locale_escape('desc_copy-start',"'",true).'\');</script>'.$n;
	flush();

	function reconnect_ftp() {
		$c =& $GLOBALS['c'];
		ftp_close($c);
		sleep(3);
		$c = ftp_connect($GLOBALS['ftpserver']);
		ftp_set_option($c, FTP_TIMEOUT_SEC, 10);
		ftp_login($c, $GLOBALS['ftpuser'], $GLOBALS['ftppw']);
		@ftp_pasv($c, true);
	}
	function list_ftp($dir, $count = 0) {
		$c =& $GLOBALS['c'];
		ftp_set_option($c, FTP_TIMEOUT_SEC, 10+$count*2);
		$result = @ftp_nlist($c, $dir);
		if ($count == 4) die('<p>'.sprintf(locale('desc_copy-failed',true),'download.php?'.SID).'</p>');
		if (!$result) {
			reconnect_ftp();
			$result = list_ftp($src, $dest, $count+1);
		}
		return $result;
	}
	function upload_ftp($src, $dest, $count = 0) {
		$c =& $GLOBALS['c'];
		@ftp_delete($c, $dest); // works better when deleting first ???
		ftp_set_option($c, FTP_TIMEOUT_SEC, 10+$count*2);
		$result = @ftp_put($c, $dest, $src, FTP_BINARY);
		if ($count == 4) die('<p>'.sprintf(locale('desc_copy-failed',true),'download.php?'.SID).'</p>');
		if (!$result) {
			reconnect_ftp();
			upload_ftp($src, $dest, $count+1);
		}
	}
	function copy_ftp($src, $dest) {
		$c =& $GLOBALS['c'];
		global $n, $filecount;
		static $i = 0;
		if ($handle = opendir($src)) {
			$folders = list_ftp(dirname($dest));
			if (!in_array($dest, $folders)) {
				ftp_mkdir($c, $dest);
			}
			while (false !== ($file = readdir($handle))) {
				if($file != '.' && $file != '..') {
					if (is_file($src.'/'.$file)) {
						$i++;
						$display = substr($src.'/'.$file, 14);
						echo '<script type="text/javascript">$("#status").text(\''.locale_escape('desc_copy-start',"'",true).' '.$display.'\');</script>'.$n;
						echo '<script type="text/javascript">drawProgressBar("#progressbar", 20, "em", "#2784f5", "#ccc", '.(0.15+$i/$filecount*0.85).');</script>'.$n;
						flush();
						upload_ftp($src.'/'.$file, $dest.'/'.$file);
					} elseif (is_dir($src.'/'.$file)) {
						copy_ftp($src.'/'.$file, $dest.'/'.$file);
					}
				}
			}
			closedir($handle);
		}
	}
	upload_ftp('../data/update/admin/update/version.txt', $ftpdir.'/admin/update/version.txt');
	copy_ftp('../data/update', $ftpdir);
	ftp_close($c);

	function unlink_r($dir) {
		if ($handle = opendir($dir)) {
			while (false !== ($file = readdir($handle))) {
				if($file != '.' && $file != '..') {
					if (is_file($dir.'/'.$file)) {
						unlink($dir.'/'.$file);
					} elseif (is_dir($dir.'/'.$file)) {
						unlink_r($dir.'/'.$file);
					}
				}
			}
			closedir($handle);
			rmdir($dir);
		}
	}
	unlink_r('../data/update');
	unlink('../data/update.tar.gz');

	echo '<p>'.locale('desc_copy-finished',true).'</p>'.$n;
	echo '<p><a href="index.php?'.SID.'">'.locale('link_next',true).'</a></p>';
	echo '<script type="text/javascript">$("#status").text(\''.locale_escape('desc_finished',"'",true).'\');</script>'.$n;
}
?>

</body>
</html>

==> cms-db_v0.8.1.tar.gz: admin/update/download.php <==
<?php
/*  cms-db  Copyright (C) 2007-2010 Jan Hoffmann
    This program comes with ABSOLUTELY NO WARRANTY; for details see /admin/version.php.
    This is free software, and you are welcome to redistribute it under certain conditions; see /admin/version.php for details.  */

define('cms-db', 'backend');

chdir('../');
include('checkuser.inc.php');
checkuser('root');
include('locale.inc.php');
$locale = new LocalizingClass('update');
?>
<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Strict//EN"
     "http://www.w3.org/TR/xhtml1/DTD/xhtml1-strict.dtd">
<html xmlns="http://www.w3.org/1999/xhtml">
<head>
<title><?php locale('title_download') ?></title>
<meta http-equiv="content-type" content="text/html; charset=utf-8" />
<link rel="stylesheet" type="text/css" href="../style.css" />
<script type="text/javascript" src="../jquery.js"></script>
<script type="text/javascript" src="../progressbar.js"></script>
<link rel="stylesheet" type="text/css" href="../progressbar.css" />
</head>
<body>

<h1><?php locale('title_download') ?></h1>
<?php
$n = "\n";
echo '<p id="progressbar">&nbsp;</p>'.$n;
echo '<p id="status" style="font-weight: bold; font-size: 1.1em">&nbsp;</p>'.$n;
echo '<script type="text/javascript">$("#status").text(\''.locale_escape('desc_ftpconn-test',"'",true).'\');</script>'.$n;
echo '<script type="text/javascript">drawProgressBar("#progressbar", 20, "em", "#2784f5", "#ccc", 0);</script>'.$n;
flush();

$error = false;
include('../data/settings/ftp.inc.php');
$c = ftp_connect($ftpserver);
if ($c !== false) {
	@ftp_set_option($c, FTP_TIMEOUT_SEC, 10);
	@ftp_pasv($c, true);
	if (@ftp_login($c, $ftpuser, $ftppw)) {
		$folders = ftp_nlist($c, $ftpdir);
		if ($folders !== false) {
			if (in_array($ftpdir.'/admin', $folders)
			&& in_array($ftpdir.'/data', $folders)
			&& in_array($ftpdir.'/functions.inc.php', $folders)) {
				echo '<p>'.locale('desc_ftpconn-established',true).'</p>'.$n;
				echo '<script type="text/javascript">drawProgressBar("#progressbar", 20, "em", "#2784f5", "#ccc", 0.05);</script>'.$n;
				flush();
			} else { $error = true; }
		} else { $error = true; }
	} else { $error = true; }
} else { $error = true; }

if ($error) {
	echo '<p>'.sprintf(locale('desc_change-ftpsettings',true),'download.php?'.SID).'</p>';
	echo '<p><a href="../ftpsettings.php?download=true&'.SID.csrf_protection_get_html_ret().'">'.locale('link_change-ftpsettings',true).'</a></p>';
	echo '<script type="text/javascript">$("#status").text(\''.locale_escape('title_error',"'",true).'\');</script>'.$n;
} else {
	echo '<script type="text/javascript">$("#status").text(\''.locale_escape('desc_download-start',"'",true).'\');</script>'.$n;
	flush();

	$version = trim(file_get_contents('../data/version.txt'));
	$curl_version = curl_version();
	$useragent = 'cms-db/'.$version.' libcurl/'.$curl_version['version'];

	$q = $_GET['q'];
	$ch = curl_init();
	curl_setopt($ch, CURLOPT_URL, 'http://update.cms-db.de/update/v1/api.php?version-unstable'); // update as soon as stable version is available
	curl_setopt($ch, CURLOPT_RETURNTRANSFER, 1);
	curl_setopt($ch, CURLOPT_USERAGENT, $useragent);
	$version = curl_exec($ch);
	curl_close($ch);

	$ch = curl_init();
	curl_setopt($ch, CURLOPT_URL, 'http://update.cms-db.de/update/v1/api.php?download/'.$version);
	curl_setopt($ch, CURLOPT_RETURNTRANSFER, 1);
	curl_setopt($ch, CURLOPT_USERAGENT, $useragent);
	$url = curl_exec($ch);
	curl_close($ch);

	$ch = curl_init();
	$fp = fopen('../data/update.tar.gz', 'wb+');
	curl_setopt($ch, CURLOPT_URL, $url);
	curl_setopt($ch, CURLOPT_FILE, $fp);
	curl_setopt($ch, CURLOPT_HEADER, 0);
	curl_setopt($ch, CURLOPT_USERAGENT, $useragent);
	curl_exec($ch);
	curl_close($ch);
	fclose($fp);

	echo '<p>'.locale('desc_download-finished',true).'</p>'.$n;
	echo '<script type="text/javascript">drawProgressBar("#progressbar", 20, "em", "#2784f5", "#ccc", 0.10);</script>'.$n;
	flush();



	echo '<script type="text/javascript">$("#status").text(\''.locale_escape('desc_extract-start',"'",true).'\');</script>'.$n;
	flush();

	if (!is_dir('../data/update')) mkdir('../data/update');


	if ((@include 'Archive/Tar.php') == true) {
		$a = new Archive_Tar('../data/update.tar.gz');
		$a->extract('../data/update');
		$filecount = 0;
		function countfiles($item, $key) {
			$filecount =& $GLOBALS['filecount'];
			if ($item['typeflag'] == 0) $filecount++;
		}
		array_walk($a->listContent(), 'countfiles');
		unset($a);
	} else {
		include('tar.inc.php');
		$a = new gzip_file('../update.tar.gz'); // path relative from basedir
		$a->set_options(array('basedir' => '../data/update', 'overwrite' => 1));
		$a->extract_files();
		$filecount = count($a->files);
		unset($a);
	}

	echo '<p>'.locale('desc_extract-finished',true).'</p>'.$n;
	echo '<script type="text/javascript">drawProgressBar("#progressbar", 20, "em", "#2784f5", "#ccc", 0.15);</script>'.$n;
	flush();



	echo '<script type="text/javascript">$("#status").text(\''.locale_escape('desc_copy-start',"'",true).'\');</script>'.$n;
	flush();

	function reconnect_ftp() {
		$c =& $GLOBALS['c'];
		ftp_close($c);
		sleep(3);
		$c = ftp_connect($GLOBALS['ftpserver']);
		ftp_set_option($c, FTP_TIMEOUT_SEC, 10);
		ftp_login($c, $GLOBALS['ftpuser'], $GLOBALS['ftppw']);
		@ftp_pasv($c, true);
	}
	function list_ftp($dir, $count = 0) {
		$c =& $GLOBALS['c'];
		ftp_set_option($c, FTP_TIMEOUT_SEC, 10+$count*2);
		$result = @ftp_nlist($c, $dir);
		if ($count == 4) die('<p>'.sprintf(locale('desc_copy-failed',true),'download.php?'.SID).'</p>');
		if (!$result) {
			reconnect_ftp();
			$result = list_ftp($src, $dest, $count+1);
		}
		return $result;
	}
	function upload_ftp($src, $dest, $count = 0) {
		$c =& $GLOBALS['c'];
		@ftp_delete($c, $dest); // works better when deleting first ???
		ftp_set_option($c, FTP_TIMEOUT_SEC, 10+$count*2);
		$result = @ftp_put($c, $dest, $src, FTP_BINARY);
		if ($count == 4) die('<p>'.sprintf(locale('desc_copy-failed',true),'download.php?'.SID).'</p>');
		if (!$result) {
			reconnect_ftp();
			upload_ftp($src, $dest, $count+1);
		}
	}
	function copy_ftp($src, $dest) {
		$c =& $GLOBALS['c'];
		global $n, $filecount;
		static $i = 0;
		if ($handle = opendir($src)) {
			$folders = list_ftp(dirname($dest));
			if (!in_array($dest, $folders)) {
				ftp_mkdir($c, $dest);
			}
			while (false !== ($file = readdir($handle))) {
				if($file != '.' && $file != '..') {
					if (is_file($src.'/'.$file)) {
						$i++;
						$display = substr($src.'/'.$file, 14);
						echo '<script type="text/javascript">$("#status").text(\''.locale_escape('desc_copy-start',"'",true).' '.$display.'\');</script>'.$n;
						echo '<script type="text/javascript">drawProgressBar("#progressbar", 20, "em", "#2784f5", "#ccc", '.(0.15+$i/$filecount*0.85).');</script>'.$n;
						flush();
						upload_ftp($src.'/'.$file, $dest.'/'.$file);
					} elseif (is_dir($src.'/'.$file)) {
						copy_ftp($src.'/'.$file, $dest.'/'.$file);
					}
				}
			}
			closedir($handle);
		}
	}
	upload_ftp('../data/update/admin/update/version.txt', $ftpdir.'/admin/update/version.txt');
	copy_ftp('../data/update', $ftpdir);
	ftp_close($c);

	function unlink_r($dir) {
		if ($handle = opendir($dir)) {
			while (false !== ($file = readdir($handle))) {
				if($file != '.' && $file != '..') {
					if (is_file($dir.'/'.$file)) {
						unlink($dir.'/'.$file);
					} elseif (is_dir($dir.'/'.$file)) {
						unlink_r($dir.'/'.$file);
					}
				}
			}
			closedir($handle);
			rmdir($dir);
		}
	}
	unlink_r('../data/update');
	unlink('../data/update.tar.gz');

	echo '<p>'.locale('desc_copy-finished',true).'</p>'.$n;
	echo '<p><a href="index.php?'.SID.csrf_protection_get_html_ret().'">'.locale('link_next',true).'</a></p>';
	echo '<script type="text/javascript">$("#status").text(\''.locale_escape('desc_finished',"'",true).'\');</script>'.$n;
}
?>

</body>
</html>
